from abaqus import *
from abaqusConstants import *

import mesh

def gAxisymmFlatPunch(myModel,pgdl,igd,mnes,mxes,ges,iElmType):
	"""
	Generate axisymm flat indenter part.
	"""

	a=igd	
	a0=max(pgdl)
	b0=a0

# characteristic points  

	O=(0,0)
	A=(a,0)
	B=(0,a)
	C=(a,a)

# sketch

	mySketch=myModel.ConstrainedSketch(name="indenter",sheetSize=100)
	mySketch.Line(point1=O,point2=A)
	mySketch.Line(point1=O,point2=B)
	mySketch.Line(point1=A,point2=C)
	mySketch.Line(point1=B,point2=C)

# axis of symmetry

	mySketch.ConstructionLine(point1=O,point2=B)	

	myPart=myModel.parts["indenterPart"]
	myPart.BaseShell(sketch=mySketch)

# part sets

	myPart.Surface(name="CONTACT",
		side1Edges=(myPart.edges.findAt(((0.5*a,0,0.),)),)
	)
	myPart.Set(name="LOAD",
		edges=myPart.edges.findAt(((0.5*a,a,0.),))
	)
	myPart.Set(name="YAXIS",
		edges=myPart.edges.findAt(((0,0.5*a,0.),))
	)
	myPart.Set(name="CONTACT",
		edges=myPart.edges.findAt(((0.5*a,0.,0.),))
	)
	myPart.Set(name="BOTTOMNODE",
		vertices=myPart.vertices.findAt(((0,0,0),))
	)

# partitioning

	pSketch=myModel.ConstrainedSketch(name="partitioningIndenter",sheetSize=100)
	pSketch.Line(point1=(a0,0),point2=(a0,a))
	pSketch.Line(point1=(0,b0),point2=(a,b0))
	myPart.PartitionFaceBySketch(
		faces=(myPart.faces[0],),
		sketch=pSketch
	)

# mesh

	if iElmType=="cax4":
		myElm=mesh.ElemType(elemCode=CAX4,elemLibrary=STANDARD)
	if iElmType=="cax8":
		myElm=mesh.ElemType(elemCode=CAX8,elemLibrary=STANDARD)
	for face in myPart.faces:
		myPart.setMeshControls(
			regions=(face,),elemShape=QUAD,technique=STRUCTURED
		)
		myPart.setElementType(regions=(face,),elemTypes=(myElm,))

	myPart.seedPart(size=ges)

# mesh for contact zone a0xb0

	myPart.seedEdgeBySize(
		edges=myPart.edges.findAt(
			((0.5*a0,0,0),),((0.5*a0,b0,0),),((0.5*a0,a,0),),
			((0,0.5*b0,0),),((a0,0.5*b0,0),),((a,0.5*b0,0),),
		),
		size=mnes
	)	

# mesh for outer zone

	a1=0.5*(a0+a)
	b1=0.5*(b0+a)
	myPart.seedEdgeByBias(biasMethod=SINGLE,
		end1Edges=myPart.edges.findAt(
			((a1,0,0),),((a1,b0,0),),((a1,a,0),),),
		minSize=mnes,maxSize=ges
	)
	myPart.seedEdgeByBias(biasMethod=SINGLE,
		end1Edges=myPart.edges.findAt(
			((0,b1,0),),((a0,b1,0),),((a,b1,0),),),
		minSize=mnes,maxSize=ges
	)

	myPart.generateMesh()

