# libabaqus_particle2D.py

from abaqus import *
from abaqusConstants import *

import mesh

###	
###
###

def gAxisymmEllipsoid(myModel,pgdl,mnes,mxes,ges):
	"""
	Generate 1/4 ellipsoidal particle.
	"""

	a=pgdl[0]	# major axis radius
	b=pgdl[1]	# minor axis radius

# characteristic points 

	O=(0,0)
	A=(a,0)
	B=(0,b)
	C=(0.5*a,b*sqrt(0.75))

# sketch

	pSketch=myModel.ConstrainedSketch(name="particle",sheetSize=100)
	pSketch.Line(point1=O,point2=A)
	pSketch.Line(point1=O,point2=B)
	pSketch.Spot(point=C)
	pEllipse=pSketch.EllipseByCenterPerimeter(
		center=O,axisPoint1=A,axisPoint2=B
	)
	pSketch.autoTrimCurve(curve1=pEllipse,point1=(-a,0))

# axis of symmetry

	pSketch.ConstructionLine(point1=O,point2=B)	

	myParticlePart=myModel.parts["particlePart"]
	myParticlePart.BaseShell(sketch=pSketch)

# part sets

	myParticlePart.Set(name="XAXIS",
		edges=myParticlePart.edges.findAt(((0.5*a,0,0.),))
	)
	myParticlePart.Set(name="YAXIS",
		edges=myParticlePart.edges.findAt(((0,0.5*b,0.),))
	)

	myParticlePart.Set(name="CONTACT",
		edges=myParticlePart.edges.findAt(((C[0],C[1],0.),))
	)

	myParticlePart.Surface(name="CONTACT",
		side1Edges=(myParticlePart.edges.findAt(((C[0],C[1],0.),)),)
	)

	myParticlePart.Set(name="TOPNODE",
		vertices=myParticlePart.vertices.findAt(((B[0],B[1],0.),))
	)

	myParticlePart.Set(name="CP",
		vertices=myParticlePart.vertices.findAt(((0.,0.,0.),))
	)

	myParticlePart.Set(name="EP",
		vertices=myParticlePart.vertices.findAt(((A[0],0.,0.),))
	)
# partitioning

#	particlePartition=myModel.ConstrainedSketch(
#		name="particlePartition",sheetSize=100)
#
#	D=(0.5*a,0.5*b)	
#	Da=(0.75*a,0)
#	Db=(0,0.75*b)
#	
#	particlePartition.Line(point1=D,point2=Da)
#	particlePartition.Line(point1=D,point2=Db)
#	particlePartition.Line(point1=D,point2=C)
#	myParticlePart.PartitionFaceBySketch(
#		faces=(myParticlePart.faces.findAt(((0.5*a,0.5*b,0.),))),
#		sketch=particlePartition
#	)

# mesh

	myCAX8=mesh.ElemType(elemCode=CAX8,elemLibrary=STANDARD)
	for face in myParticlePart.faces:
		myParticlePart.setMeshControls(
			regions=(face,),elemShape=QUAD,technique=STRUCTURED
		)
		myParticlePart.setElementType(regions=(face,),elemTypes=(myCAX8,))

	myParticlePart.seedPart(size=mnes)
	myParticlePart.generateMesh()


###	
###
###

def gAxysimmTriangular(myModel,pgdl,mnes,mxes,ges):
	"""
	Generation axysimmetric 1/4 triangular particle.
	"""

	a=pgdl[0]	# particle dim along x axis
	b=pgdl[1]	# particle dim along y axis
	c=pgdl[2]	# initial contact length at the top 

# characteristic points 

	O=(0,0)
	A=(a,0)
	B=(0,b)
	C=(c,b)

# sketch

	pSketch=myModel.ConstrainedSketch(name="particle",sheetSize=100)
	pSketch.Line(point1=O,point2=A)
	pSketch.Line(point1=A,point2=C)
	pSketch.Line(point1=C,point2=B)
	pSketch.Line(point1=B,point2=O)

# axis of symmetry

	pSketch.ConstructionLine(point1=O,point2=B)

	myParticlePart=myModel.parts["particlePart"]
	myParticlePart.BaseShell(sketch=pSketch)

# part sets

	myParticlePart.Set(name="XAXIS",
		edges=myParticlePart.edges.findAt(((0.5*a,0,0),))
	)
	myParticlePart.Set(name="YAXIS",
		edges=myParticlePart.edges.findAt(((0,0.5*b,0),))
	)
	myParticlePart.Surface(name="CONTACT",
		side1Edges=myParticlePart.edges.findAt(
			((0.5*c,b,0.),),((0.5*(a+c),0.5*b,0.),)
		)
	)

# partitioning 

#	particlePartition=myModel.ConstrainedSketch(
#		name="particlePartition",sheetSize=100)
#	
#	particlePartition.Line(point1=(0.,0.5*(bb+cc)),point2=(aa,0.5*(bb+cc)))
#	particlePartition.Line(point1=(0.5*(aa+cc),0.),point2=(0.5*(aa+cc),bb))
#
#	myParticlePart.PartitionFaceBySketch(
#		faces=(myParticlePart.faces.findAt(((0.5*aa,0.5*bb,0.),))),
#		sketch=particlePartition
#	)

# mesh

#	myParticlePart.seedEdgeByBias(
#		biasMethod=SINGLE,
#		end2Edges=myParticlePart.edges.findAt(
#			((0.25*(aa+cc),0.75*(bb+cc),0.),)),
#		minSize=mnes,maxSize=ges
#	)
#	myParticlePart.seedEdgeByBias(
#		biasMethod=SINGLE,
#		end1Edges=myParticlePart.edges.findAt(
#			((0.75*(aa+cc),0.25*(bb+cc),0.),)),
#		minSize=mnes,maxSize=ges
#	)
#	myParticlePart.seedEdgeByBias(
#		biasMethod=SINGLE,
#		end2Edges=myParticlePart.edges.findAt(((aa,0.5*cc,0.),)),
#		minSize=mnes,maxSize=ges
#	)
#	myParticlePart.seedEdgeByBias(
#		biasMethod=SINGLE,
#		end1Edges=myParticlePart.edges.findAt(((0.5*cc,bb,0.),)),
#		minSize=mnes,maxSize=ges
#	)
	

